==> typescript-linq-1.0.5.tgz: package/README.md <==
#TypeScript - LINQ for ECMAScript 2015



This is an implementation of the standard LINQ operators defined by Microsoft, in TypeScript.



See: [Classification of Standard Query Operators by Manner of Execution (C#)](https://msdn.microsoft.com/en-us/library/mt693095.aspx)



This project is the successor of an earlier LINQ project in TypeScript. The earlier project used it's own implementation of the iterator pattern. The current project uses the so called "iteration protocols" which are new in ECMAScript 2015.



The project itself is a Visual Studio solution completely written with "Visual Studio Community 2015" update 3 and TypeScript version 1.8.36.0.



There is a test suite available for this library at github. A full API documentation is available online and is also available as download for offline use.



All public classes and functions have a full set of documentation comments. So there is full IntelliSense support available in the code editor.



The code compiles with the TypeScript build settings "ECMAScript version" set to "ECMAScript 6". That is in fact an alias for "ECMAScript 2015". The code passes all tests running with the node runtime V6.6.0.



Please be aware that this library is intentionally compiled into ECMAScript 2015. The library is neither tested nor designed to run on Javascript engines which doesn't support the ECMAScript 2015 standard. 



See: [typescript-linq V1.0.X](https://www.npmjs.com/package/typescript-linq) (npm package)   

See: [TypeScript-LINQ-Node-Test](https://github.com/lord-saumagen/TypeScript-LINQ-Node-Test) (Node.js test)   

See: [API-Documentation Online](http://lord-saumagen.byethost14.com/home/TypeScript-LINQ-Node-Documentation/)   

See: [API-Documentation Offline](http://lord-saumagen.byethost14.com/home/TypeScript-LINQ-Node-Documentation.zip)   

See: [Iteration protocols](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Iteration_protocols)   

See: [ECMAScript 2015](http://www.ecma-international.org/ecma-262/6.0/)   

See: [Visual Studio](https://www.visualstudio.com)   



## Installation



Run the following command in a command or terminal window:



`npm install typescript-linq`



Add an import or require statement in your code:



`import {TS} from '../node_modules/typescript-linq/TS';`



or:



`const TS = require('../node_modules/typescript-linq/TS')`



You may have to change the path to match you local setup.



##Further information



If you are looking for further information take a look at the complete project at github. 



See: [Complete project](https://github.com/lord-saumagen/TypeScript-LINQ)





##License



This software is licensed under the "Microsoft Public License".



See: [MS-PL](https://opensource.org/licenses/MS-PL")



The full license text is also available in the "Docs" directory in file "Microsoft\_Public\_License\_(MS-PL).txt".



&copy; lord.saumagen@gmail.com, 2016

==> typescript-linq-1.0.6.tgz: package/README.md <==
#TypeScript - LINQ for ECMAScript 2015



This is an implementation of the standard LINQ operators defined by Microsoft, in TypeScript.



See: [Classification of Standard Query Operators by Manner of Execution (C#)](https://msdn.microsoft.com/en-us/library/mt693095.aspx)



This project is the successor of an earlier LINQ project in TypeScript. The earlier project used it's own implementation of the iterator pattern. The current project uses the so called "iteration protocols" which are new in ECMAScript 2015.



The project itself is a Visual Studio solution completely written with "Visual Studio Community 2015" update 3 and TypeScript version 2.x.



There is a test suite available for this library at github. A full API documentation is available online and is also available as download for offline use.



All public classes and functions have a full set of documentation comments. So there is full IntelliSense support available in the code editor.



The code compiles with the TypeScript build settings "ECMAScript version" set to "ECMAScript 6". That is in fact an alias for "ECMAScript 2015". The code passes all tests running with the node runtime V6.6.0.



Please be aware that this library is intentionally compiled into ECMAScript 2015. The library is neither tested nor designed to run on Javascript engines which doesn't support the ECMAScript 2015 standard. 



See: [typescript-linq V1.0.X](https://www.npmjs.com/package/typescript-linq) (npm package)   

See: [TypeScript-LINQ-Node-Test](https://github.com/lord-saumagen/TypeScript-LINQ-Node-Test) (Node.js test)   

See: [API-Documentation Online](http://lord-saumagen.byethost14.com/home/TypeScript-LINQ-Node-Documentation/)   

See: [API-Documentation Offline](http://lord-saumagen.byethost14.com/home/TypeScript-LINQ-Node-Documentation.zip)   

See: [Iteration protocols](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Iteration_protocols)   

See: [ECMAScript 2015](http://www.ecma-international.org/ecma-262/6.0/)   

See: [Visual Studio](https://www.visualstudio.com)   



## Installation



Run the following command in a command or terminal window:



`npm install typescript-linq`



Add an import or require statement in your code:



`import {TS} from './node_modules/typescript-linq/TS';`



or:



`const TS = require('typescript-linq/TS.js')`



You may have to change the path to match you local setup.



##Further information



If you are looking for further information take a look at the complete project at github. 



See: [Complete project](https://github.com/lord-saumagen/TypeScript-LINQ)





##License



This software is licensed under the "Microsoft Public License".



See: [MS-PL](https://opensource.org/licenses/MS-PL")



The full license text is also available in the "Docs" directory in file "Microsoft\_Public\_License\_(MS-PL).txt".



&copy; lord.saumagen@gmail.com, 2016
